"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MsgClientImpl = void 0;
const binary_1 = require("../../../binary");
const tx_1 = require("./tx");
class MsgClientImpl {
    rpc;
    constructor(rpc) {
        this.rpc = rpc;
    }
    /* AuthorizeCircuitBreaker allows a super-admin to grant (or revoke) another
     account's circuit breaker permissions. */
    authorizeCircuitBreaker = async (request) => {
        const data = tx_1.MsgAuthorizeCircuitBreaker.encode(request).finish();
        const promise = this.rpc.request("cosmos.circuit.v1.Msg", "AuthorizeCircuitBreaker", data);
        return promise.then(data => tx_1.MsgAuthorizeCircuitBreakerResponse.decode(new binary_1.BinaryReader(data)));
    };
    /* TripCircuitBreaker pauses processing of Msg's in the state machine. */
    tripCircuitBreaker = async (request) => {
        const data = tx_1.MsgTripCircuitBreaker.encode(request).finish();
        const promise = this.rpc.request("cosmos.circuit.v1.Msg", "TripCircuitBreaker", data);
        return promise.then(data => tx_1.MsgTripCircuitBreakerResponse.decode(new binary_1.BinaryReader(data)));
    };
    /* ResetCircuitBreaker resumes processing of Msg's in the state machine that
     have been been paused using TripCircuitBreaker. */
    resetCircuitBreaker = async (request) => {
        const data = tx_1.MsgResetCircuitBreaker.encode(request).finish();
        const promise = this.rpc.request("cosmos.circuit.v1.Msg", "ResetCircuitBreaker", data);
        return promise.then(data => tx_1.MsgResetCircuitBreakerResponse.decode(new binary_1.BinaryReader(data)));
    };
}
exports.MsgClientImpl = MsgClientImpl;
//# sourceMappingURL=tx.rpc.msg.js.map