"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MsgClientImpl = void 0;
const binary_1 = require("../../../binary");
const tx_1 = require("./tx");
class MsgClientImpl {
    rpc;
    constructor(rpc) {
        this.rpc = rpc;
    }
    /* StoreCode to submit Wasm code to the system */
    storeCode = async (request) => {
        const data = tx_1.MsgStoreCode.encode(request).finish();
        const promise = this.rpc.request("cosmwasm.wasm.v1.Msg", "StoreCode", data);
        return promise.then(data => tx_1.MsgStoreCodeResponse.decode(new binary_1.BinaryReader(data)));
    };
    /* InstantiateContract creates a new smart contract instance for the given
      code id. */
    instantiateContract = async (request) => {
        const data = tx_1.MsgInstantiateContract.encode(request).finish();
        const promise = this.rpc.request("cosmwasm.wasm.v1.Msg", "InstantiateContract", data);
        return promise.then(data => tx_1.MsgInstantiateContractResponse.decode(new binary_1.BinaryReader(data)));
    };
    /* InstantiateContract2 creates a new smart contract instance for the given
      code id with a predictable address */
    instantiateContract2 = async (request) => {
        const data = tx_1.MsgInstantiateContract2.encode(request).finish();
        const promise = this.rpc.request("cosmwasm.wasm.v1.Msg", "InstantiateContract2", data);
        return promise.then(data => tx_1.MsgInstantiateContract2Response.decode(new binary_1.BinaryReader(data)));
    };
    /* Execute submits the given message data to a smart contract */
    executeContract = async (request) => {
        const data = tx_1.MsgExecuteContract.encode(request).finish();
        const promise = this.rpc.request("cosmwasm.wasm.v1.Msg", "ExecuteContract", data);
        return promise.then(data => tx_1.MsgExecuteContractResponse.decode(new binary_1.BinaryReader(data)));
    };
    /* Migrate runs a code upgrade/ downgrade for a smart contract */
    migrateContract = async (request) => {
        const data = tx_1.MsgMigrateContract.encode(request).finish();
        const promise = this.rpc.request("cosmwasm.wasm.v1.Msg", "MigrateContract", data);
        return promise.then(data => tx_1.MsgMigrateContractResponse.decode(new binary_1.BinaryReader(data)));
    };
    /* UpdateAdmin sets a new   admin for a smart contract */
    updateAdmin = async (request) => {
        const data = tx_1.MsgUpdateAdmin.encode(request).finish();
        const promise = this.rpc.request("cosmwasm.wasm.v1.Msg", "UpdateAdmin", data);
        return promise.then(data => tx_1.MsgUpdateAdminResponse.decode(new binary_1.BinaryReader(data)));
    };
    /* ClearAdmin removes any admin stored for a smart contract */
    clearAdmin = async (request) => {
        const data = tx_1.MsgClearAdmin.encode(request).finish();
        const promise = this.rpc.request("cosmwasm.wasm.v1.Msg", "ClearAdmin", data);
        return promise.then(data => tx_1.MsgClearAdminResponse.decode(new binary_1.BinaryReader(data)));
    };
    /* UpdateInstantiateConfig updates instantiate config for a smart contract */
    updateInstantiateConfig = async (request) => {
        const data = tx_1.MsgUpdateInstantiateConfig.encode(request).finish();
        const promise = this.rpc.request("cosmwasm.wasm.v1.Msg", "UpdateInstantiateConfig", data);
        return promise.then(data => tx_1.MsgUpdateInstantiateConfigResponse.decode(new binary_1.BinaryReader(data)));
    };
    /* UpdateParams defines a governance operation for updating the x/wasm
     module parameters. The authority is defined in the keeper.
    
     Since: 0.40 */
    updateParams = async (request) => {
        const data = tx_1.MsgUpdateParams.encode(request).finish();
        const promise = this.rpc.request("cosmwasm.wasm.v1.Msg", "UpdateParams", data);
        return promise.then(data => tx_1.MsgUpdateParamsResponse.decode(new binary_1.BinaryReader(data)));
    };
    /* SudoContract defines a governance operation for calling sudo
     on a contract. The authority is defined in the keeper.
    
     Since: 0.40 */
    sudoContract = async (request) => {
        const data = tx_1.MsgSudoContract.encode(request).finish();
        const promise = this.rpc.request("cosmwasm.wasm.v1.Msg", "SudoContract", data);
        return promise.then(data => tx_1.MsgSudoContractResponse.decode(new binary_1.BinaryReader(data)));
    };
    /* PinCodes defines a governance operation for pinning a set of
     code ids in the wasmvm cache. The authority is defined in the keeper.
    
     Since: 0.40 */
    pinCodes = async (request) => {
        const data = tx_1.MsgPinCodes.encode(request).finish();
        const promise = this.rpc.request("cosmwasm.wasm.v1.Msg", "PinCodes", data);
        return promise.then(data => tx_1.MsgPinCodesResponse.decode(new binary_1.BinaryReader(data)));
    };
    /* UnpinCodes defines a governance operation for unpinning a set of
     code ids in the wasmvm cache. The authority is defined in the keeper.
    
     Since: 0.40 */
    unpinCodes = async (request) => {
        const data = tx_1.MsgUnpinCodes.encode(request).finish();
        const promise = this.rpc.request("cosmwasm.wasm.v1.Msg", "UnpinCodes", data);
        return promise.then(data => tx_1.MsgUnpinCodesResponse.decode(new binary_1.BinaryReader(data)));
    };
    /* StoreAndInstantiateContract defines a governance operation for storing
     and instantiating the contract. The authority is defined in the keeper.
    
     Since: 0.40 */
    storeAndInstantiateContract = async (request) => {
        const data = tx_1.MsgStoreAndInstantiateContract.encode(request).finish();
        const promise = this.rpc.request("cosmwasm.wasm.v1.Msg", "StoreAndInstantiateContract", data);
        return promise.then(data => tx_1.MsgStoreAndInstantiateContractResponse.decode(new binary_1.BinaryReader(data)));
    };
    /* RemoveCodeUploadParamsAddresses defines a governance operation for
     removing addresses from code upload params.
     The authority is defined in the keeper. */
    removeCodeUploadParamsAddresses = async (request) => {
        const data = tx_1.MsgRemoveCodeUploadParamsAddresses.encode(request).finish();
        const promise = this.rpc.request("cosmwasm.wasm.v1.Msg", "RemoveCodeUploadParamsAddresses", data);
        return promise.then(data => tx_1.MsgRemoveCodeUploadParamsAddressesResponse.decode(new binary_1.BinaryReader(data)));
    };
    /* AddCodeUploadParamsAddresses defines a governance operation for
     adding addresses to code upload params.
     The authority is defined in the keeper. */
    addCodeUploadParamsAddresses = async (request) => {
        const data = tx_1.MsgAddCodeUploadParamsAddresses.encode(request).finish();
        const promise = this.rpc.request("cosmwasm.wasm.v1.Msg", "AddCodeUploadParamsAddresses", data);
        return promise.then(data => tx_1.MsgAddCodeUploadParamsAddressesResponse.decode(new binary_1.BinaryReader(data)));
    };
}
exports.MsgClientImpl = MsgClientImpl;
//# sourceMappingURL=tx.rpc.msg.js.map